==> pylips-0.0.11-py3-none-any.whl: pylips/face/FacePresets.py <==
chili = {
            'background_color': '#d63e3e',
            'eyeball_color': '#ffffff',
            'iris_color': '#4db818',
            'eye_size': 150,
            'eye_height': 80,
            'eye_separation': 450,
            'iris_size': 90,
            'pupil_scale': 0.8,
            'eye_shine': True,
            'eyelid_color': '#d63e3e',
            'nose_color': '#e38fae',
            'nose_vertical_position': 10,
            'nose_width': 80,
            'nose_height': -25,
            'mouth_color': '#222222',
            'mouth_width': 480,
            'mouth_height': 30,
            'mouth_thickness': 18,
            'brow_color': '#222222',
            'brow_width': 150,
            'brow_height': 120,
            'brow_thickness': 20
        }

gingerbreadman = {
            'background_color': '#8c6f5a',
            'eyeball_color': '#ffffff00',
            'iris_color': '#ffffff',
            'eye_size': 150,
            'eye_height': 80,
            'eye_separation': 300,
            'iris_size': 30,
            'pupil_scale': 0,
            'eye_shine': True,
            'eyelid_color': '#8c6f5a',
            'nose_color': '#9bbce0',
            'nose_vertical_position': 0,
            'nose_width': 0,
            'nose_height': 0,
            'mouth_color': '#9e0216',
            'mouth_width': 220,
            'mouth_height': 30,
            'mouth_thickness': 18,
            'brow_color': '#7bbac9',
            'brow_width': 70,
            'brow_height': 120,
            'brow_thickness': 20
        }

cutie = {
            'background_color': '#cccccc',
            'eyeball_color': '#ffffff',
            'iris_color': '#43d932',
            'eye_size': 150,
            'eye_height': 80,
            'eye_separation': 400,
            'iris_size': 90,
            'pupil_scale': 0.8,
            'eye_shine': True,
            'eyelid_color': '#cccccc',
            'nose_color': '#9bbce0',
            'nose_vertical_position': 0,
            'nose_width': 0,
            'nose_height': 0,
            'mouth_color': '#222222',
            'mouth_width': 320,
            'mouth_height': 30,
            'mouth_thickness': 18,
            'brow_color': '#222222',
            'brow_width': 110,
            'brow_height': 120,
            'brow_thickness': 20
        }

==> pylips-0.0.15-py3-none-any.whl: pylips/face/FacePresets.py <==
black_screen = {
            'background_color': '#000000',
            'eyeball_color': '#000000',
            'iris_color': '#000000',
            'eye_size': 150,
            'eye_height': 80,
            'eye_separation': 450,
            'iris_size': 90,
            'pupil_scale': 0.8,
            'eye_shine': False,
            'eyelid_color': '#000000',
            'nose_color': '#000000',
            'nose_vertical_position': 10,
            'nose_width': 80,
            'nose_height': -25,
            'mouth_color': '#000000',
            'mouth_width': 480,
            'mouth_height': 30,
            'mouth_thickness': 18,
            'brow_color': '#000000',
            'brow_width': 150,
            'brow_height': 210,
            'brow_thickness': 20
}

high_contrast = {
            'background_color': '#bbbbbb',
            'eyeball_color': '#ffffff',
            'iris_color': '#ffffff',
            'eye_size': 150,
            'eye_height': 80,
            'eye_separation': 350,
            'iris_size': 90,
            'pupil_scale': 0.6,
            'eye_shine': False,
            'eyelid_color': '#bbbbbb',
            'nose_color': '#ffffff00',
            'nose_vertical_position': 10,
            'nose_width': 80,
            'nose_height': -25,
            'mouth_color': '#000000',
            'mouth_width': 480,
            'mouth_height': 30,
            'mouth_thickness': 25,
            'brow_color': '#000000',
            'brow_width': 110,
            'brow_height': 210,
            'brow_thickness': 20
}

default = {
            'background_color': '#D7E4F5',
            'eyeball_color': '#ffffff',
            'iris_color': '#800080',
            'eye_size': 140,
            'eye_height': 80,
            'eye_separation': 400,
            'iris_size': 80,
            'pupil_scale': .7,
            'eye_shine': True,
            'eyelid_color': '#D7E4F5',
            'nose_color': '#ff99cc',
            'nose_vertical_position': -40,
            'nose_width': 0,
            'nose_height': 0,
            'mouth_color': '#2c241b',
            'mouth_width': 450,
            'mouth_height': 20,
            'mouth_thickness': 18,
            'brow_color': '#2c241b',
            'brow_width': 130,
            'brow_height': 210,
            'brow_thickness': 18
        }


chili = {
            'background_color': '#d63e3e',
            'eyeball_color': '#ffffff',
            'iris_color': '#4db818',
            'eye_size': 150,
            'eye_height': 80,
            'eye_separation': 450,
            'iris_size': 90,
            'pupil_scale': 0.8,
            'eye_shine': True,
            'eyelid_color': '#d63e3e',
            'nose_color': '#e38fae',
            'nose_vertical_position': 10,
            'nose_width': 80,
            'nose_height': -25,
            'mouth_color': '#222222',
            'mouth_width': 480,
            'mouth_height': 30,
            'mouth_thickness': 18,
            'brow_color': '#222222',
            'brow_width': 150,
            'brow_height': 210,
            'brow_thickness': 20
        }

gingerbreadman = {
            'background_color': '#8c6f5a',
            'eyeball_color': '#ffffff00',
            'iris_color': '#ffffff',
            'eye_size': 150,
            'eye_height': 80,
            'eye_separation': 300,
            'iris_size': 30,
            'pupil_scale': 0,
            'eye_shine': True,
            'eyelid_color': '#8c6f5a',
            'nose_color': '#9bbce0',
            'nose_vertical_position': 0,
            'nose_width': 0,
            'nose_height': 0,
            'mouth_color': '#9e0216',
            'mouth_width': 220,
            'mouth_height': 30,
            'mouth_thickness': 18,
            'brow_color': '#7bbac9',
            'brow_width': 70,
            'brow_height': 210,
            'brow_thickness': 20
        }

cutie = {
            'background_color': '#aaaaaa',
            'eyeball_color': '#ffffff',
            'iris_color': '#43d932',
            'eye_size': 150,
            'eye_height': 80,
            'eye_separation': 400,
            'iris_size': 90,
            'pupil_scale': 0.8,
            'eye_shine': True,
            'eyelid_color': '#aaaaaa',
            'nose_color': '#9bbce0',
            'nose_vertical_position': 0,
            'nose_width': 0,
            'nose_height': 0,
            'mouth_color': '#222222',
            'mouth_width': 320,
            'mouth_height': 30,
            'mouth_thickness': 18,
            'brow_color': '#222222',
            'brow_width': 110,
            'brow_height': 210,
            'brow_thickness': 20
        }
